==> haskell-tasty-checklist-1.0.8.0-1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-tasty-checklist.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 tasty-checklist
version:              1.0.8.0
visibility:           public
id:                   tasty-checklist-1.0.8.0-6HqBMRb4VEYGUjQCFt5qGf
key:                  tasty-checklist-1.0.8.0-6HqBMRb4VEYGUjQCFt5qGf
license:              ISC
copyright:            Kevin Quick
maintainer:           kquick@galois.com
author:               Kevin Quick
synopsis:             Check multiple items during a tasty test
description:
    Allows the test to check a number of items during a test and
    only signal pass or fail when the end if the checklist is reached.

    Also provides an easy method to check multiple derived values from
    a single input value.

category:             Testing
abi:                  900d6ca0ee2204055612e64503b18ccf
exposed:              True
exposed-modules:      Test.Tasty.Checklist
import-dirs:          /usr/lib/ghc-9.6.6/site-local/tasty-checklist-1.0.8.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/tasty-checklist-1.0.8.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/tasty-checklist-1.0.8.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-tasty-checklist
hs-libraries:         HStasty-checklist-1.0.8.0-6HqBMRb4VEYGUjQCFt5qGf
depends:
    base-4.18.2.1 containers-0.6.7 exceptions-0.10.7
    parameterized-utils-2.1.10.0-K9k2WU6P2flDyJ9do22sx8 text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-tasty-checklist/html/tasty-checklist.haddock

haddock-html:         /usr/share/doc/haskell-tasty-checklist/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-tasty-checklist-1.0.8.0-4-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-tasty-checklist.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 tasty-checklist
version:              1.0.8.0
visibility:           public
id:                   tasty-checklist-1.0.8.0-1yeiJdrzlPVD0zDeusyYkn
key:                  tasty-checklist-1.0.8.0-1yeiJdrzlPVD0zDeusyYkn
license:              ISC
copyright:            Kevin Quick
maintainer:           kquick@galois.com
author:               Kevin Quick
synopsis:             Check multiple items during a tasty test
description:
    Allows the test to check a number of items during a test and
    only signal pass or fail when the end if the checklist is reached.

    Also provides an easy method to check multiple derived values from
    a single input value.

category:             Testing
abi:                  db5612439ca2b1ae0a8c8489b9e89d1c
exposed:              True
exposed-modules:      Test.Tasty.Checklist
import-dirs:          /usr/lib/ghc-9.6.6/site-local/tasty-checklist-1.0.8.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/tasty-checklist-1.0.8.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/tasty-checklist-1.0.8.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-tasty-checklist
hs-libraries:         HStasty-checklist-1.0.8.0-1yeiJdrzlPVD0zDeusyYkn
depends:
    base-4.18.2.1 containers-0.6.7 exceptions-0.10.7
    parameterized-utils-2.1.11.0-BdXPBQmwjWo1EUYdY1GgcP text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-tasty-checklist/html/tasty-checklist.haddock

haddock-html:         /usr/share/doc/haskell-tasty-checklist/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
